@@ -15,6 +15,7 @@ from feedcrawler.external_sites.web_search.sites.content_all_dw import dw_search
 from feedcrawler.external_sites.web_search.sites.content_all_fx import fx_search_results
 from feedcrawler.external_sites.web_search.sites.content_all_hw import hw_search_results
 from feedcrawler.external_sites.web_search.sites.content_all_nk import nk_search_results
+from feedcrawler.external_sites.web_search.sites.content_all_nx import nx_search_results
 from feedcrawler.providers.common_functions import check_is_ignored
 from feedcrawler.providers.common_functions import check_is_site
 from feedcrawler.providers.common_functions import encode_base64
@@ -38,9 +39,12 @@ def search_web(title, only_content_all=False, only_content_shows=False, only_fas
     fx = hostnames.get('fx')
     hw = hostnames.get('hw')
     nk = hostnames.get('nk')
+    nx = hostnames.get('nx')
     sj = hostnames.get('sj')
     sf = hostnames.get('sf')
 
+    force_ignore_in_web_search = CrawlerConfig('FeedCrawler').get('force_ignore_in_web_search')
+
     specific_season = re.match(r'^(.*),(s\d{1,3})$', title.lower())
     specific_episode = re.match(r'^(.*),(s\d{1,3}e\d{1,3})$', title.lower())
     if specific_season:
@@ -84,19 +88,25 @@ def search_web(title, only_content_all=False, only_content_shows=False, only_fas
             hw_search = 'https://' + hw + '/?s=' + bl_query
         else:
             hw_search = None
+        if nx:
+            nx_search = 'https://' + nx + '/api/frontend/search/' + bl_query
+        else:
+            nx_search = None
 
         if only_fast:
             fx_search = None
+            nx_search = None
         if only_slow:
             by_search = None
             hw_search = None
 
-        async_results = get_urls_async([by_search, dw_search, fx_search, hw_search])
+        async_results = get_urls_async([by_search, dw_search, fx_search, hw_search, nx_search])
 
         by_results = []
         dw_results = []
         fx_results = []
         hw_results = []
+        nx_results = []
 
         for res in async_results:
             if check_is_site(res[1]) == 'BY':
@@ -107,6 +117,8 @@ def search_web(title, only_content_all=False, only_content_shows=False, only_fas
                 fx_results = fx_search_results(fx_content_to_soup(res[0]), bl_query)
             elif check_is_site(res[1]) == 'HW':
                 hw_results = hw_search_results(res[0], quality, title)
+            elif check_is_site(res[1]) == 'NX':
+                nx_results = nx_search_results(res[0], quality, title)
 
         if nk and not only_slow:
             nk_search = post_url('https://' + nk + "/search",
@@ -117,46 +129,43 @@ def search_web(title, only_content_all=False, only_content_shows=False, only_fas
 
         password = ""
         for result in by_results:
-            if "480p" in quality and check_release_not_sd(result[0]):
-                continue
             unrated.append(
                 [rate(result[0], ignore), encode_base64(result[1] + "|" + password), result[0] + " (BY)"])
 
         password = fx.split('.')[0]
         for result in fx_results:
-            if "480p" in quality and check_release_not_sd(result[0]):
-                continue
             # title is intentionally sent with the password, so we can detect the correct link when downloading
             unrated.append([rate(result[0], ignore), encode_base64(result[1] + "|" + password + "|" + result[0]),
                             result[0] + " (FX)"])
 
         password = dw.split('.')[0]
         for result in dw_results:
-            if "480p" in quality and check_release_not_sd(result[0]):
-                continue
             unrated.append(
                 [rate(result[0], ignore), encode_base64(result[1] + "|" + password), result[0] + " (DW)"])
 
         password = hw.split('.')[0]
         for result in hw_results:
-            if "480p" in quality and check_release_not_sd(result[0]):
-                continue
             unrated.append(
                 [rate(result[0], ignore), encode_base64(result[1] + "|" + password), result[0] + " (HW)"])
 
         password = nk.split('.')[0].capitalize()
         for result in nk_results:
-            if "480p" in quality and check_release_not_sd(result[0]):
-                continue
             unrated.append(
                 [rate(result[0], ignore), encode_base64(result[1] + "|" + password), result[0] + " (NK)"])
 
+        password = nx.split('.')[0]
+        for result in nx_results:
+            unrated.append(
+                [rate(result[0], ignore), encode_base64(result[1] + "|" + password), result[0] + " (NX)"])
+
         rated = sorted(unrated, reverse=True)
 
         results = []
         i = 0
 
         for result in rated:
+            if force_ignore_in_web_search and check_is_ignored(result[2], ignore):
+                continue
             res = {"payload": result[1], "title": result[2]}
             results.append(res)
             i += 1
@@ -194,7 +203,8 @@ def search_web(title, only_content_all=False, only_content_shows=False, only_fas
             sf_query = keep_alphanumeric_with_special_characters(title)
             sf_search = get_url('https://' + sf + '/api/v2/search?q=' + sf_query + '&ql=DE')
             try:
-                sf_results = json.loads(sf_search)["result"]
+                clean_sf_search = BeautifulSoup(sf_search, "html.parser").body.text
+                sf_results = json.loads(clean_sf_search)["result"]
             except:
                 sf_results = []
         else:
