@@ -10,7 +10,7 @@ from feedcrawler.providers.common_functions import simplified_search_term_in_tit
 
 
 def dw_search_results(content, resolution, search_term):
-    content = BeautifulSoup(content, 'html5lib')
+    content = BeautifulSoup(content, "html.parser")
     links = content.findAll("article")
     results = []
     for link in links:
