@@ -21,11 +21,11 @@ class CrawlerConfig(object):
             ("prefix", "str", ""),
             ("interval", "int", "60"),
             ("flaresolverr", "str", ""),
-            ("flaresolverr_proxy", "str", ""),
             ("english", "bool", "False"),
             ("surround", "bool", ""),
             ("one_mirror_policy", "bool", "False"),
-            ("packages_per_myjd_page", "int", "3")
+            ("packages_per_myjd_page", "int", "3"),
+            ("force_ignore_in_web_search", "bool", "False"),
         ],
         'Hostnames': [
             ("fx", "str", ""),
@@ -47,6 +47,7 @@ class CrawlerConfig(object):
         ],
         'Notifications': [
             ("telegram", "str", ""),
+            ("discord", "str", ""),
             ("pushbullet", "str", ""),
             ("pushover", "str", ""),
             ("homeassistant", "str", "")
