@@ -11,7 +11,6 @@ from urllib.error import URLError
 from urllib.parse import urlencode
 
 from feedcrawler.providers import shared_state
-from feedcrawler.providers.common_functions import site_blocked_with_flaresolverr
 from feedcrawler.providers.config import CrawlerConfig
 from feedcrawler.providers.http_requests.request_handler import request
 from feedcrawler.providers.sqlite_database import FeedDb
@@ -28,14 +27,6 @@ def get_flaresolverr_url():
     return False
 
 
-def get_flaresolverr_proxy():
-    config = CrawlerConfig('FeedCrawler')
-    flaresolverr_proxy = config.get("flaresolverr_proxy")
-    if flaresolverr_proxy:
-        return flaresolverr_proxy
-    return False
-
-
 def pickle_db(key, value):
     try:
         FeedDb('flaresolverr').delete(key)
@@ -56,6 +47,7 @@ def unpickle_db(key):
 
 
 def clean_flaresolverr_session():
+    # ToDo: as soon as FlareSolverr 3.0 supports sessions we need to send a delete request to the session endpoint
     return FeedDb('flaresolverr').reset()
 
 
@@ -136,8 +128,6 @@ def flaresolverr_request(flaresolverr_url, url, method, params, headers, redirec
             clean_flaresolverr_session()
             print("Fehler im HTTP-Request (ohne Flaresolverr)", e)
 
-    flaresolverr_proxy = get_flaresolverr_proxy()
-
     text = ''
     response_headers = {}
 
@@ -162,9 +152,6 @@ def flaresolverr_request(flaresolverr_url, url, method, params, headers, redirec
     if method == 'post':
         flaresolverr_payload["postData"] = encoded_params
 
-    if site_blocked_with_flaresolverr(url) and flaresolverr_proxy:
-        flaresolverr_payload["proxy"] = {"url": flaresolverr_proxy}
-
     json_response = request(flaresolverr_url, method="POST", json=flaresolverr_payload)
 
     status_code = json_response.status_code
@@ -178,10 +165,11 @@ def flaresolverr_request(flaresolverr_url, url, method, params, headers, redirec
         if redirect_url:
             try:
                 url = response['solution']['url']
+                shared_state.logger.debug("Der Abruf der Redirect-URL war mit FlareSolverr erfolgreich.")
             except:
                 shared_state.logger.debug("Der Abruf der Redirect-URL war mit FlareSolverr fehlerhaft.")
 
-        shared_state.logger.debug("Der Abruf der Redirect-URL war mit FlareSolverr erfolgreich.")
+        shared_state.logger.debug("Der Abruf der URL war mit FlareSolverr erfolgreich.")
 
         text = response['solution']['response']
         response_headers = response['solution']['headers']
