@@ -331,11 +331,11 @@ def app_container():
                         "prefix": general_conf.get("prefix"),
                         "interval": to_int(general_conf.get("interval")),
                         "flaresolverr": general_conf.get("flaresolverr"),
-                        "flaresolverr_proxy": general_conf.get("flaresolverr_proxy"),
                         "english": general_conf.get("english"),
                         "surround": general_conf.get("surround"),
                         "one_mirror_policy": general_conf.get("one_mirror_policy"),
                         "packages_per_myjd_page": to_int(general_conf.get("packages_per_myjd_page")),
+                        "force_ignore_in_web_search": general_conf.get("force_ignore_in_web_search"),
                     },
                     "hosters": {
                         "rapidgator": hosters.get("rapidgator"),
@@ -354,10 +354,11 @@ def app_container():
                         "ironfiles": hosters.get("ironfiles"),
                     },
                     "alerts": {
+                        "telegram": alerts.get("telegram"),
+                        "discord": alerts.get("discord"),
                         "pushbullet": alerts.get("pushbullet"),
                         "pushover": alerts.get("pushover"),
                         "homeassistant": alerts.get("homeassistant"),
-                        "telegram": alerts.get("telegram"),
                     },
                     "plex": {
                         "url": plex.get("url"),
@@ -476,20 +477,21 @@ def app_container():
                 interval = '5'
             section.save("interval", interval)
             section.save("flaresolverr", to_str(data['general']['flaresolverr']))
-            section.save("flaresolverr_proxy", to_str(data['general']['flaresolverr_proxy']))
             section.save("english", to_str(data['general']['english']))
             section.save("surround", to_str(data['general']['surround']))
             section.save("one_mirror_policy", to_str(data['general']['one_mirror_policy']))
             section.save("packages_per_myjd_page", to_str(data['general']['packages_per_myjd_page']))
+            section.save("force_ignore_in_web_search", to_str(data['general']['force_ignore_in_web_search']))
 
             section = CrawlerConfig("Crawljobs")
             section.save("autostart", to_str(data['crawljobs']['autostart']))
             section.save("subdir", to_str(data['crawljobs']['subdir']))
 
             section = CrawlerConfig("Notifications")
+            section.save("telegram", to_str(data['alerts']['telegram']))
+            section.save("discord", to_str(data['alerts']['discord']))
             section.save("pushbullet", to_str(data['alerts']['pushbullet']))
             section.save("pushover", to_str(data['alerts']['pushover']))
-            section.save("telegram", to_str(data['alerts']['telegram']))
             section.save("homeassistant", to_str(data['alerts']['homeassistant']))
 
             section = CrawlerConfig("Hosters")
@@ -809,6 +811,8 @@ def app_container():
                 search_shorthands.append("BY")
             if nk:
                 search_shorthands.append("NK")
+            if nx:
+                search_shorthands.append("NX")
             if sj:
                 search_shorthands.append("SJ")
             if dj:
@@ -906,18 +910,6 @@ def app_container():
                         "NK": check("NK_flaresolverr", db_status),
                         "NX": check("NX_flaresolverr", db_status),
                         "WW": check("WW_flaresolverr", db_status)
-                    },
-                    "flaresolverr_proxy": {
-                        "SJ": check("SJ_flaresolverr_proxy", db_status),
-                        "DJ": check("DJ_flaresolverr_proxy", db_status),
-                        "SF": check("SF_flaresolverr_proxy", db_status),
-                        "BY": check("BY_flaresolverr_proxy", db_status),
-                        "FX": check("FX_flaresolverr_proxy", db_status),
-                        "HW": check("HW_flaresolverr_proxy", db_status),
-                        "FF": check("FF_flaresolverr_proxy", db_status),
-                        "NK": check("NK_flaresolverr_proxy", db_status),
-                        "NX": check("NX_flaresolverr_proxy", db_status),
-                        "WW": check("WW_flaresolverr_proxy", db_status)
                     }
                 }
             }
@@ -2088,9 +2080,9 @@ def attempt_download(package_name, links, password, ids):
             epoch = int(time.time())
             for item in already_added:
                 if item[0] == package_name:
-                    if int(item[1]) + 30 > epoch:
-                        print(package_name + u" wurde in den letzten 30 Sekunden bereits hinzugefügt")
-                        return abort(500, package_name + u" wurde in den letzten 30 Sekunden bereits hinzugefügt")
+                    if int(item[1]) + 5 > epoch:
+                        print(package_name + u" wurde in den letzten 5 Sekunden bereits hinzugefügt")
+                        return abort(500, package_name + u" wurde in den letzten 5 Sekunden bereits hinzugefügt")
                     else:
                         already_added.remove(item)
 
